@@ -8,13 +8,6 @@ from strange_case.nodes import *
 from strange_case.processors import *
 from strange_case.nodes import Node
 
-notifier = None
-try:
-    from gntp import notifier
-    import socket
-except ImportError:
-    pass
-
 
 def require_package(pkg, reason=None):
     sys.stderr.write("\033[1m" + pkg + "\033[0m is required.\n  > pip install " + pkg + "\n")
@@ -158,10 +151,7 @@ def strange_case(config):
     # processors.build_page_tree - it needs special handling here.
     root_node = build_node(config, site_path, deploy_path, '')[0]
     Registry.set('root', root_node)
-    from time import clock
-    start = clock()
     root_node.generate()
-    print 'generate:', clock() - start
 
     # configurators can respond to the 'on_finish' hook
     for configurator in Registry.configurators:
@@ -192,26 +182,6 @@ def strange_case(config):
             sys.stderr.write("\033[31mrmdir\033[0m \033[1m" + p_rel + "\033[0m\n")
             os.removedirs(p)
 
-    if notifier:
-        try:
-            growl = notifier.GrowlNotifier(
-                applicationName="StrangeCase",
-                notifications=["New Messages"],
-                defaultNotifications=["New Messages"],
-            )
-            growl.register()
-
-            # Send one message
-            growl.notify(
-                noteType="New Messages",
-                title="StrangeCase site generated",
-                description="site is available at:\n"
-                    "{config[deploy_path]}"\
-                    .format(config=config),
-            )
-        except socket.error:
-            pass
-
 
 def get_configurators(config):
     configurators = []
